==============================
Communication and Coordination
==============================

Project leader
--------------

Guido Stevens coordinates the Plone Intranet Project.

.. note::

    If you have any questions, contact him at guido.stevens@quaive.com


Quaive Board
----------------

Investment decisions and roadmap strategy are decided upon by the
Quaive Board.

The Board has a private mailing list at board@quaive.com.

.. note::

    If you're a Board member but not on that list, please contact Guido at 
    info@ploneintranet.org.


Development Team
----------------

Community edition code lives on github, in the
`Plone Intranet organization <https://github.com/ploneintranet>`_

You're welcome to submit issues and pull requests there.

We use the #ploneintranet IRC channel on Freenode:
http://webchat.freenode.net/?channels=ploneintranet

The canonical place for documentation is http://docs.ploneintranet.org for the community
edition, and http://docs.quaive.net (requires login) for the enterprise edition.


